bayespy.inference.vmp.nodes.beta.BetaDistribution.compute_mask_to_parent
========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.beta

.. automethod:: BetaDistribution.compute_mask_to_parent